import { Component, Input, forwardRef, ViewChild } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { AutoCompleteDirective } from '../auto-complete';
import { RebirthNGConfig } from '../rebirth-ng.config';
var SelectComponent = (function () {
    function SelectComponent(rebirthNgConfig) {
        this.readonly = true;
        this.onChange = function (_) { return null; };
        this.onTouched = function () { return null; };
        this.iconDown = rebirthNgConfig.select.iconDown;
        this.formatter = rebirthNgConfig.autoComplete.formatter;
    }
    SelectComponent.prototype.writeValue = function (value) {
        this.selectedItem = value;
    };
    SelectComponent.prototype.registerOnChange = function (fn) {
        this.onChange = fn;
    };
    SelectComponent.prototype.registerOnTouched = function (fn) {
        this.onTouched = fn;
    };
    SelectComponent.prototype.setDisabledState = function (isDisabled) {
        this.disabled = isDisabled;
    };
    SelectComponent.prototype.popup = function (event) {
        if (!this.disabled) {
            this.autoComplete.toggle(event);
        }
    };
    SelectComponent.prototype.onSelectedChange = function (value) {
        this.onTouched();
        this.onChange(value);
    };
    SelectComponent.decorators = [
        { type: Component, args: [{
                    selector: 're-select',
                    template: "\n    <div class=\"input-group select-panel\" (click)=\"popup($event)\"><input class=\"form-control select-control\" [minLength]=\"0\" [disabled]=\"disabled\" [readonly]=\"readonly\" [placeholder]=\"placeholder\" [(ngModel)]=\"selectedItem\" (ngModelChange)=\"onSelectedChange($event)\" reAutoComplete [dataSource]=\"options\" [formatter]=\"formatter\"><div class=\"input-group-addon\"><i class=\"select-down-icon {{iconDown}}\"></i></div></div>\n  ",
                    styles: ["\n    .select-control:not([disabled]),.select-panel{cursor:pointer}::ng-deep .dropdown-menu{width:95%}::ng-deep .dropdown-menu .dropdown-item{white-space:normal!important}\n  "],
                    exportAs: 'select',
                    providers: [{
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(function () { return SelectComponent; }),
                            multi: true
                        }]
                },] },
    ];
    /** @nocollapse */
    SelectComponent.ctorParameters = function () { return [
        { type: RebirthNGConfig, },
    ]; };
    SelectComponent.propDecorators = {
        "readonly": [{ type: Input },],
        "disabled": [{ type: Input },],
        "placeholder": [{ type: Input },],
        "options": [{ type: Input },],
        "iconDown": [{ type: Input },],
        "formatter": [{ type: Input },],
        "autoComplete": [{ type: ViewChild, args: [AutoCompleteDirective,] },],
    };
    return SelectComponent;
}());
export { SelectComponent };
//# sourceMappingURL=select.component.js.map